@@ -29,6 +29,7 @@ class Samples:
                  max_allow_x=1e13,
                  max_allow_y=1e13,
                  line_limit=None,
+                 remove_null=True,
                  **kwargs):
 
         """
@@ -101,9 +102,23 @@ class Samples:
 
             # read from data dictionary
             self.x_name = feat_names
+
+            clean_list = []
+            if remove_null:
+                for elem_dict in temp:
+                    val_chk = list((elem in (None, '', ' ', 'null', 'NULL', '<null>', '<NULL>')) or
+                                   (elem in (int, float) and np.isnan(elem))
+                                   for elem in elem_dict.values())
+                    if any(val_chk):
+                        continue
+                    else:
+                        clean_list.append(elem_dict)
+            else:
+                clean_list = temp
+
             self.x = np.array(list(list(samp_dict[feat_name] for feat_name in feat_names)
-                                   for samp_dict in temp))
-            self.y = np.array(list(samp_dict[label_colname] for samp_dict in temp))
+                                   for samp_dict in clean_list))
+            self.y = np.array(list(samp_dict[label_colname] for samp_dict in clean_list))
             self.y_name = label_colname
 
             # if band name dictionary is provided
@@ -114,10 +129,23 @@ class Samples:
             temp = Handler(filename=csv_file).read_from_csv(return_dicts=True,
                                                             line_limit=line_limit)
 
+            clean_list = []
+            if remove_null:
+                for elem_dict in temp:
+                    val_chk = list((elem in (None, '', ' ', 'null', 'NULL', '<null>', '<NULL>')) or
+                                   (elem in (int, float) and np.isnan(elem))
+                                   for elem in elem_dict.values())
+                    if any(val_chk):
+                        continue
+                    else:
+                        clean_list.append(elem_dict)
+            else:
+                clean_list = temp
+
             # read from data dictionary
-            self.x_name = list(temp[0])
+            self.x_name = list(clean_list[0].keys())
             self.x = np.array(list(list(samp_dict[feat_name] for feat_name in self.x_name)
-                                   for samp_dict in temp))
+                                   for samp_dict in clean_list))
 
         else:
             ValueError("No data found for label.")
